#Author: Linus Svenberg

#The following packages are needed for the script to run

library(ggplot2)
library(tidyverse)
library(ggpubr)
library(ggfortify)
library(multcompView)

#setwd("~/
#remove the hashtag and specify the location of datafiles in the setwd-commando so that the code may run
dataset = read_delim("ANOVA_tbl2.csv",
                     delim=";",
                     col_names=TRUE,
                     trim_ws=TRUE)
#First we want to remove any zeros, as to remove sample entries that did not detect the designated compound

dataset[dataset==0] <- NA


dataset_ber1 = dataset%>%
  filter(Plant =="Ber")%>%
  drop_na()


dataset_pap1 = dataset%>%
  filter(Plant=="Pap")%>%
  drop_na()

dataset_tor1 = dataset%>%
  filter(Plant=="Tor")%>%
  drop_na()

#So based on the fact that some compounds only have two entries, which means that cannot undergo statistical evaluation,
#we therefore remove those entries from the list as well

dataset_ber2 = dataset_ber1[-c(35:40,46:47),]

dataset_pap2 = dataset_pap1[-c(1:2,13:14,15:17,21:22,27:30),]

dataset_tor2 = dataset_tor1[-c(24:25,29:34),]

dataset2 = rbind(dataset_ber2,dataset_pap2,dataset_tor2)
#We now make our individual datasets for the compounds that have more than two entries. With this, it is narrowed down
#to 5 compounds.
#
#alpha-pinene
dataset_ap = dataset2%>%
  filter(Compound=="alpha-Pinene")


#beta-pinene
dataset_bp = dataset2%>%
  filter(Compound=="beta-Pinene")


#3-octanone
dataset_3o = dataset2%>%
  filter(Compound=="3-octanone")

#beta-myrcene
dataset_bm = dataset2%>%
  filter(Compound=="beta-myrcene")

#Citronellol
dataset_cl = dataset2%>%
  filter(Compound=="Citronellol")

#We then perfrom our 1-way ANOVA along with the post-hoc Tukey test
aov_ap=(aov(rel_area_pct~Plant,data=dataset_ap))
TukeyHSD(aov_ap, conf.level = 0.95)
aov_bp=(aov(rel_area_pct~Plant,data=dataset_bp))
TukeyHSD(aov_bp, conf.level = 0.95)
aov_3o=(aov(rel_area_pct~Plant,data=dataset_3o))
TukeyHSD(aov_3o, conf.level = 0.95)
aov_bm=(aov(rel_area_pct~Plant,data=dataset_bm))
TukeyHSD(aov_bm, conf.level = 0.95)
aov_cl=(aov(rel_area_pct~Plant,data=dataset_cl))
TukeyHSD(aov_cl, conf.level = 0.95)

